@@ -46,7 +46,9 @@ from neutron_lib.api.definitions import extraroute
 from neutron_lib.api.definitions import extraroute_atomic
 from neutron_lib.api.definitions import filter_validation
 from neutron_lib.api.definitions import fip64
+from neutron_lib.api.definitions import fip_distributed
 from neutron_lib.api.definitions import fip_pf_description
+from neutron_lib.api.definitions import fip_pf_detail
 from neutron_lib.api.definitions import fip_pf_port_range
 from neutron_lib.api.definitions import fip_port_details
 from neutron_lib.api.definitions import firewall_v2
@@ -74,6 +76,7 @@ from neutron_lib.api.definitions import metering_source_and_destination_filters
 from neutron_lib.api.definitions import multiprovidernet
 from neutron_lib.api.definitions import network
 from neutron_lib.api.definitions import network_availability_zone
+from neutron_lib.api.definitions import network_cascade_delete
 from neutron_lib.api.definitions import network_ip_availability
 from neutron_lib.api.definitions import network_mtu
 from neutron_lib.api.definitions import network_mtu_writable
@@ -81,6 +84,8 @@ from neutron_lib.api.definitions import network_segment_range
 from neutron_lib.api.definitions import pagination
 from neutron_lib.api.definitions import port
 from neutron_lib.api.definitions import port_device_profile
+from neutron_lib.api.definitions import port_hint_ovs_tx_steering
+from neutron_lib.api.definitions import port_hints
 from neutron_lib.api.definitions import port_mac_address_override
 from neutron_lib.api.definitions import port_mac_address_regenerate
 from neutron_lib.api.definitions import port_numa_affinity_policy
@@ -187,6 +192,8 @@ _ALL_API_DEFINITIONS = {
     filter_validation,
     fip64,
     firewall_v2,
+    fip_distributed,
+    fip_pf_detail,
     fip_port_details,
     flavors,
     floating_ip_port_forwarding,
@@ -214,6 +221,7 @@ _ALL_API_DEFINITIONS = {
     multiprovidernet,
     network,
     network_availability_zone,
+    network_cascade_delete,
     network_ip_availability,
     network_mtu,
     network_mtu_writable,
@@ -221,6 +229,8 @@ _ALL_API_DEFINITIONS = {
     pagination,
     port,
     port_device_profile,
+    port_hints,
+    port_hint_ovs_tx_steering,
     port_mac_address_override,
     port_mac_address_regenerate,
     port_numa_affinity_policy,
