@@ -15,8 +15,6 @@ from neutron_lib import constants
 
 KNOWN_ATTRIBUTES = (
     'admin_state_up',
-    'auth_key',
-    'auth_type',
     'allocation_pools',
     'cidr',
     'default_prefixlen',
@@ -25,10 +23,8 @@ KNOWN_ATTRIBUTES = (
     'device_id',
     'device_owner',
     'dns_nameservers',
-    'dst_ip',
     'enable_dhcp',
     'enable_ndp_proxy',
-    'external_gateways',
     'fixed_ips',
     'gateway_ip',
     'host_routes',
@@ -40,10 +36,6 @@ KNOWN_ATTRIBUTES = (
     'mac_address',
     'max_prefixlen',
     'min_prefixlen',
-    'min_rx',
-    'min_tx',
-    'mode',
-    'multiplier',
     'name',
     'network_id',
     'port_id',
@@ -53,12 +45,10 @@ KNOWN_ATTRIBUTES = (
     'qos_policy_id',
     'service_types',
     constants.SHARED,
-    'src_ip',
     'status',
     'subnets',
     'subnetpool_id',
-    'tenant_id',
-    'type'
+    'tenant_id'
 )
 
 KNOWN_RESOURCES = (
@@ -94,7 +84,6 @@ KNOWN_EXTENSIONS = (
     'allowed-address-pairs',
     'auto-allocated-topology',
     'availability_zone',
-    'bfd-monitor',
     'binding',
     'data-plane-status',
     'project-default-networks',
@@ -129,12 +118,12 @@ KNOWN_EXTENSIONS = (
     'metering',
     'metering_source_and_destination_filters',
     'multi-provider',
-    'multiple-external-gateways',
     'net-mtu',
     'network-ip-availability',
     'network-segment-range',
     'network_availability_zone',
     'pagination',
+    'port-mac-address-override',
     'port-resource-request',
     'port-security',
     'project-id',
@@ -147,9 +136,12 @@ KNOWN_EXTENSIONS = (
     'qos-port-network-policy',
     'qos-pps-minimum',
     'qos-pps-minimum-rule-alias',
+    'qos-rule-type-filter',
     'qos-rules-alias',
     'quotas',
     'quota-check-limit',
+    'port-hints',
+    'port-hint-ovs-tx-steering',
     'rbac-address-group',
     'rbac-address-scope',
     'rbac-bgpvpn',
@@ -196,6 +188,10 @@ KNOWN_EXTENSIONS = (
     # https://opendev.org/openstack/networking-sfc:
     'flow_classifier',
     'sfc',
+
+    # https://opendev.org/openstack/tap-as-a-service
+    'taas',
+    'taas-vlan-filter',
 )
 
 KNOWN_KEYWORDS = (
